@@ -24,12 +24,12 @@
 
 name = "OpenObject-Library"
 appname = name.lower()
-version = '2.0.2'
+version = '2.0.3'
 copyright = "Copyright (C) 2009-2012 Christophe CHAUVET <christophe.chauvet@syleam.fr>"
 description = "Web Services library OpenObject Framework"
 author = "Christophe CHAUVET"
 author_email = "christophe.chauvet@syleam.fr"
-url = "https://launchpad.net/openobject-library"
+url = "https://github.com/syleam/openobject-library"
 long_description = """OpenObject-Library is a library to manage
 OpenObject Server
 """
